Inheritance
===========

#:after:submodule2/index:paragraph:this_is_the_first_sample_paragraph#

This is a NEW paragraph AFTER the first one.


#:before:submodule2/index:paragraph:this_is_the_second_sample_paragraph#

This is a NEW NEW paragraph BEFORE the second one.


#:replace:submodule2/index:paragraph:this_is_the_third_sample_paragraph#

This one replaces the THIRD paragraph!
